R__EXTERN Dacc In;

Dacc In;

void
openDacc(void) {
   //----------------------------------  Create a data access object.
   const char* InPath = gSystem->Getenv("DMTINPUT");
   if (InPath && *InPath) {
      cout << "Connecting default input accessor (In) to " << InPath << endl;
      In.addFile(InPath);
      In.open();
   } else {
      cout << "Default input accessor (In) not opened. No input file specified."
	   << endl;
   }
}

void
closeDacc(void) {
   In.close();
}
